| Title: | Colour palettes based on Metallica studio album covers |
|---|---|
| Description: | Colour palettes based on Metallica studio album covers. |
| Authors: | John MacKintosh [aut, cre] |
| Maintainer: | John MacKintosh <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-01 08:57:22 UTC |
| Source: | https://github.com/johnmackintosh/metallicart |
anger palette
anger_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_anger(n, type = "discrete", reverse = FALSE, ...) scale_colour_anger(n, type = "discrete", reverse = FALSE, ...) scale_fill_anger(n, type = "discrete", reverse = FALSE, ...)anger_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_anger(n, type = "discrete", reverse = FALSE, ...) scale_colour_anger(n, type = "discrete", reverse = FALSE, ...) scale_fill_anger(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(anger_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_anger() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_anger() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_anger()library(scales) show_col(anger_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_anger() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_anger() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_anger()
combo palette
combo_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_combo(n, type = "discrete", reverse = FALSE, ...) scale_colour_combo(n, type = "discrete", reverse = FALSE, ...) scale_fill_combo(n, type = "discrete", reverse = FALSE, ...)combo_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_combo(n, type = "discrete", reverse = FALSE, ...) scale_colour_combo(n, type = "discrete", reverse = FALSE, ...) scale_fill_combo(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(combo_pal()(10),,labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_combo() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_combo() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_combo()library(scales) show_col(combo_pal()(10),,labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_combo() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_combo() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_combo()
hardwired palette
hardwired_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_hardwired(n, type = "discrete", reverse = FALSE, ...) scale_colour_hardwired(n, type = "discrete", reverse = FALSE, ...) scale_fill_hardwired(n, type = "discrete", reverse = FALSE, ...)hardwired_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_hardwired(n, type = "discrete", reverse = FALSE, ...) scale_colour_hardwired(n, type = "discrete", reverse = FALSE, ...) scale_fill_hardwired(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(hardwired_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_hardwired() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_hardwired() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_hardwired()library(scales) show_col(hardwired_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_hardwired() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_hardwired() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_hardwired()
justice palette
justice_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_justice(n, type = "discrete", reverse = FALSE, ...) scale_colour_justice(n, type = "discrete", reverse = FALSE, ...) scale_fill_justice(n, type = "discrete", reverse = FALSE, ...)justice_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_justice(n, type = "discrete", reverse = FALSE, ...) scale_colour_justice(n, type = "discrete", reverse = FALSE, ...) scale_fill_justice(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(justice_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_justice() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_justice() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_justice()library(scales) show_col(justice_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_justice() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_justice() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_justice()
killem palette
killem_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_killem(n, type = "discrete", reverse = FALSE, ...) scale_colour_killem(n, type = "discrete", reverse = FALSE, ...) scale_fill_killem(n, type = "discrete", reverse = FALSE, ...)killem_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_killem(n, type = "discrete", reverse = FALSE, ...) scale_colour_killem(n, type = "discrete", reverse = FALSE, ...) scale_fill_killem(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(killem_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_killem() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_killem() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_killem()library(scales) show_col(killem_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_killem() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_killem() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_killem()
lightning palette
lightning_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_lightning(n, type = "discrete", reverse = FALSE, ...) scale_colour_lightning(n, type = "discrete", reverse = FALSE, ...) scale_fill_lightning(n, type = "discrete", reverse = FALSE, ...)lightning_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_lightning(n, type = "discrete", reverse = FALSE, ...) scale_colour_lightning(n, type = "discrete", reverse = FALSE, ...) scale_fill_lightning(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(lightning_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_lightning() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_lightning() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_lightning()library(scales) show_col(lightning_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_lightning() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_lightning() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_lightning()
load palette
load_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_load(n, type = "discrete", reverse = FALSE, ...) scale_colour_load(n, type = "discrete", reverse = FALSE, ...) scale_fill_load(n, type = "discrete", reverse = FALSE, ...)load_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_load(n, type = "discrete", reverse = FALSE, ...) scale_colour_load(n, type = "discrete", reverse = FALSE, ...) scale_fill_load(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(load_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_load() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_load() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_load()library(scales) show_col(load_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_load() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_load() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_load()
magnetic palette
magnetic_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_magnetic(n, type = "discrete", reverse = FALSE, ...) scale_colour_magnetic(n, type = "discrete", reverse = FALSE, ...) scale_fill_magnetic(n, type = "discrete", reverse = FALSE, ...)magnetic_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_magnetic(n, type = "discrete", reverse = FALSE, ...) scale_colour_magnetic(n, type = "discrete", reverse = FALSE, ...) scale_fill_magnetic(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(magnetic_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_magnetic() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_magnetic() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_magnetic()library(scales) show_col(magnetic_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_magnetic() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_magnetic() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_magnetic()
R package that contains color palettes based on colours on Metallica studio album covers.
metalli_palette(name, n, type = c("discrete", "continuous"))metalli_palette(name, n, type = c("discrete", "continuous"))
name |
Name of palette. Select one:
|
n |
Number of colors desired. Some palettes contain 7 colors which were picked 'by hand'
The |
type |
Either continuous or discrete. |
Yep, even the black album.
This package is based on the nycpalettes package: https://github.com/kellycotton/nycpalettes
A vector of colors.
metalli_palette("anger")metalli_palette("anger")
metallica palette
metallica_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_metallica(n, type = "discrete", reverse = FALSE, ...) scale_colour_metallica(n, type = "discrete", reverse = FALSE, ...) scale_fill_metallica(n, type = "discrete", reverse = FALSE, ...)metallica_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_metallica(n, type = "discrete", reverse = FALSE, ...) scale_colour_metallica(n, type = "discrete", reverse = FALSE, ...) scale_fill_metallica(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(metallica_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_metallica() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_metallica() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_metallica()library(scales) show_col(metallica_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_metallica() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_metallica() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_metallica()
puppets palette
puppets_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_puppets(n, type = "discrete", reverse = FALSE, ...) scale_colour_puppets(n, type = "discrete", reverse = FALSE, ...) scale_fill_puppets(n, type = "discrete", reverse = FALSE, ...)puppets_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_puppets(n, type = "discrete", reverse = FALSE, ...) scale_colour_puppets(n, type = "discrete", reverse = FALSE, ...) scale_fill_puppets(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(puppets_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_puppets() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_puppets() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_puppets()library(scales) show_col(puppets_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_puppets() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_puppets() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_puppets()
reload palette
reload_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_reload(n, type = "discrete", reverse = FALSE, ...) scale_colour_reload(n, type = "discrete", reverse = FALSE, ...) scale_fill_reload(n, type = "discrete", reverse = FALSE, ...)reload_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_reload(n, type = "discrete", reverse = FALSE, ...) scale_colour_reload(n, type = "discrete", reverse = FALSE, ...) scale_fill_reload(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(reload_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_reload() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_reload() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_reload()library(scales) show_col(reload_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_reload() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_reload() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_reload()
seasons palette
seasons_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_seasons(n, type = "discrete", reverse = FALSE, ...) scale_colour_seasons(n, type = "discrete", reverse = FALSE, ...) scale_fill_seasons(n, type = "discrete", reverse = FALSE, ...)seasons_pal(n, type = c("discrete", "continuous"), reverse = FALSE) scale_color_seasons(n, type = "discrete", reverse = FALSE, ...) scale_colour_seasons(n, type = "discrete", reverse = FALSE, ...) scale_fill_seasons(n, type = "discrete", reverse = FALSE, ...)
n |
number of colors |
type |
discrete or continuous |
reverse |
reverse order, Default: FALSE |
... |
Arguments passed on to
|
library(scales) show_col(seasons_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_seasons() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_seasons() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_seasons()library(scales) show_col(seasons_pal()(10),labels = FALSE) library(ggplot2) ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_color_seasons() ggplot(airquality, aes(x = Day, y = Temp, group = as.factor(Month), color = as.factor(Month))) + geom_point(size = 2.5) + scale_colour_seasons() ggplot(mpg, aes(displ)) + geom_histogram(aes(fill = class), col = "black", size = 0.1) + scale_fill_seasons()